/* ***** BEGIN LICENSE BLOCK *****
 * Version: GPL 2.0
 *
 * This code is part of DownThemAll! - dTa!
 * Copyright © 2004-2006 Federico Parodi and Stefano Verna.
 * 
 * See notice.txt and gpl.txt for details.
 *
 * ***** END LICENSE BLOCK ***** */
 
// DTA context overlay
var DTA_ContextOverlay = {

	isLinkOpenable : function(t) {
		return t.match(/^(http|ftp|https):\/\/.+/i)
	},

	trim : function(t) {
		return t.replace(/^[ \t_]+|[ \t_]+$/gi, "").replace(/(_){2,}/g, "_");
	},
	
	addLinksToArray : function(lnks, urls, ref) {
		for (var i = 0; i < lnks.length; ++i) {
			// remove anchor from url
			var link = lnks[i].href.replace(/#.*/gi, "");
			// if it's valid and it's new
			if (this.isLinkOpenable(link) && !(link in urls)) {
				// add to array
				var elem = new Object();
				elem.url = link;
				elem.refPage = ref;
				if (lnks[i].title)
					elem.ultDescription = this.trim(lnks[i].title);
				elem.description = this.trim(this.extractDescription(lnks[i]));
				urls[link] = elem;
				urls.length++;
			}
		}
	},
	
	addImagesToArray : function(lnks, images, ref)	{
		if (lnks && lnks.length) {
			for (var i = 0; i<lnks.length; ++i) 
				// if it's valid and it's new
				if (this.isLinkOpenable(lnks[i].src) && !(lnks[i].src in images)) {
					// add to array
					var elem = new Object();
					elem.url = lnks[i].src;
					elem.refPage = ref;
					if (lnks[i].hasAttributes()) {
						if (lnks[i].alt)
							elem.description = this.trim(lnks[i].alt);
						else if (lnks[i].title)
							elem.description = this.trim(lnks[i].title);
					}
					images[lnks[i].src] = elem;
					images.length++;
				}
		}
	},
	
	addLinks : function(win, urls, images) {
		try {
			if (win.document) {
				// fill links array
				this.addLinksToArray (win.document.links, urls, win.document.URL);
				// fill images/embedded array
				this.addImagesToArray (win.document.images, images, win.document.URL);
				this.addImagesToArray (win.document.embeds, images, win.document.URL);
			}
		} catch(e) {}
		if (win.frames && win.frames.length > 0) {
			for (var i = 0; i<win.frames.length; i++)
				this.addLinks(win.frames[i], urls, images);
		}
	},
	
	findLinks : function(turbo) {try {
		var urls = new Object();
		urls.length = 0;
		var images = new Object();
		images.length = 0;
	
		var win = document.commandDispatcher.focusedWindow.top;
		this.addLinks(win, urls, images);
		DTA_AddingFunctions.saveLinkArray(turbo, urls, images);
		
		} catch(e) {}
		return 0;
	},
	
	findSingleLink : function(turbo) {try {
		var win = document.commandDispatcher.focusedWindow.top;
		
		// salgo su fino a trovare un link
		var cur = gContextMenu.target;
		while (!("tagName" in cur) || cur.tagName.toLowerCase() != "a")			
			cur = cur.parentNode;
			
		DTA_AddingFunctions.saveSingleLink(turbo, cur.href, document.commandDispatcher.focusedWindow.document.URL, this.extractDescription(cur));
	} catch (e) {}
	},
	
	init : function() {
		var dta;
		try {
			dta = document.getElementById("contentAreaContextMenu");
			if (dta) { dta.addEventListener("popupshowing", this.onHideContext, false); }
			dta = document.getElementById("menu_ToolsPopup")
			if (dta) { dta.addEventListener("popupshowing", this.onHideTool, false); }
			dta = document.getElementById("messagePaneContext")
			if (dta) { dta.addEventListener("popupshowing", this.onHideContext, false); }
			dta = document.getElementById("taskPopup")
			if (dta) { dta.addEventListener("popupshowing", this.onHideTool, false); }
		} catch(e){ Components.utils.reportError("Error in DTA_ContextOverlay::init: "+e); }
	},
	
	onHideContext : function() {try {
		var menu = DTA_AddingFunctions.getPreference("extensions.dta.context.menu", "1,1,0").split(",");
		var context = DTA_AddingFunctions.getPreference("extensions.dta.context.compactmenu", false);
		document.getElementById("dta-context-menu").hidden = !context;
		document.getElementById("context-dta-pref").hidden = !(parseInt(menu[2]) && !context);
		document.getElementById("submenu-dta-pref").hidden = !(parseInt(menu[2]) && context);
		document.getElementById("dta-separator").hidden = !(parseInt(menu[2]) && context);
		var cm = gContextMenu;
		if (cm && cm.onLink) {
			document.getElementById("context-dta").hidden = true;
			document.getElementById("submenu-dta").hidden = true;
			document.getElementById("context-tdta").hidden = true;
			document.getElementById("submenu-tdta").hidden = true;
			document.getElementById("context-dta-savelink").hidden = !(parseInt(menu[0]) && !context);
			document.getElementById("submenu-dta-savelink").hidden = !(parseInt(menu[0]) && context);
			document.getElementById("context-dta-savelinkt").hidden = !(parseInt(menu[1]) && !context);
			document.getElementById("submenu-dta-savelinkt").hidden = !(parseInt(menu[1]) && context);
		} else {
			document.getElementById("context-dta-savelink").hidden = true;
			document.getElementById("submenu-dta-savelink").hidden = true;
			document.getElementById("context-dta-savelinkt").hidden = true;
			document.getElementById("submenu-dta-savelinkt").hidden = true;
			document.getElementById("context-dta").hidden = !(parseInt(menu[0]) && !context);
			document.getElementById("submenu-dta").hidden = !(parseInt(menu[0]) && context);
			document.getElementById("context-tdta").hidden = !(parseInt(menu[1]) && !context);
			document.getElementById("submenu-tdta").hidden = !(parseInt(menu[1]) && context);
		}
	} catch(e) {
		alert("DTAHide(): " + e);
	}
	},
	
	onHideTool : function() {try {
		var menuTool = DTA_AddingFunctions.getPreference("extensions.dta.tool.menu", "1,1,1").split(",");
		var contextTool = DTA_AddingFunctions.getPreference("extensions.dta.tool.compactmenu", true); // checks if  the user wants a submenu
	
		document.getElementById("dta-tool").hidden = !(parseInt(menuTool[0]) && (!contextTool));
		document.getElementById("turbo-tool").hidden = !(parseInt(menuTool[1]) && (!contextTool));
		document.getElementById("dta-manager-tool").hidden = !(parseInt(menuTool[2]) && (!contextTool));
		document.getElementById("dta-menu").hidden = !contextTool; 
		document.getElementById("dta-Popup").hidden = !contextTool;
		document.getElementById("dta-tool-popup").hidden = !parseInt(menuTool[0]);
		document.getElementById("turbo-tool-popup").hidden = !parseInt(menuTool[1]);
		document.getElementById("dta-manager-tool-popup").hidden = !parseInt(menuTool[2]);
		document.getElementById("dta-help-tool").hidden = !("openHelp" in window);
	} catch(e) {
		alert("DTAHideTool(): " + e);
	}
	},
	
	extractDescription : function(child) {try {
		var risultato = "";
		if (child.hasChildNodes()) {
			for (var x = 0; x < child.childNodes.length; x++) {
				var c = child.childNodes[x];
	
				if (c.nodeValue && c.nodeValue != "")
					risultato += c.nodeValue.replace(/(\n|\r)*/gi, "").replace(/(\s){2,}/gi, " ");
	
				if (c.nodeType == 1) 
					risultato = risultato + this.extractDescription(c);
	
				if (c.hasAttributes()) {
					if (c.title) 
						risultato = risultato + c.title + " ";	
					else if (c.alt) 
						risultato = risultato + c.alt + " ";
				}	
			}
		}
		} catch(e) {}
		return risultato;
	}
}

window.addEventListener("load", function() {DTA_ContextOverlay.init();}, false);

